@@ -907,10 +907,28 @@ class DataIO:
     used to pass dataset-specific I/O parameters to the particular HDMFIO backend.
     """
 
-    @docval({'name': 'data', 'type': 'array_data', 'doc': 'the data to be written', 'default': None})
+    @docval({'name': 'data',
+             'type': 'array_data',
+             'doc': 'the data to be written',
+             'default': None},
+            {'name': 'dtype',
+             'type': (type, np.dtype),
+             'doc': 'the data type of the dataset. Not used if data is specified.',
+             'default': None},
+            {'name': 'shape',
+             'type': tuple,
+             'doc': 'the shape of the dataset. Not used if data is specified.',
+             'default': None})
     def __init__(self, **kwargs):
-        data = popargs('data', kwargs)
+        data, dtype, shape = popargs('data', 'dtype', 'shape', kwargs)
+        if data is not None:
+            if dtype is not None:
+                raise ValueError("Setting the dtype when data is not None is not supported")
+            if shape is not None:
+                raise ValueError("Setting the shape when data is not None is not supported")
         self.__data = data
+        self.__dtype = dtype
+        self.__shape = shape
 
     def get_io_params(self):
         """
@@ -928,8 +946,20 @@ class DataIO:
         """Set the wrapped data object"""
         if self.__data is not None:
             raise ValueError("cannot overwrite 'data' on DataIO")
+        if not (self.__dtype is None and self.__shape is None):
+            raise ValueError("Setting data when dtype and shape are not None is not supported")
         self.__data = val
 
+    @property
+    def dtype(self):
+        """Get the wrapped data object"""
+        return self.__dtype or self.__getattr__("dtype")
+
+    @property
+    def shape(self):
+        """Get the wrapped data object"""
+        return self.__shape or self.__getattr__("shape")
+
     def __copy__(self):
         """
         Define a custom copy method for shallow copy..
